'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _read = require('read');

var _read2 = _interopRequireDefault(_read);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var CONFIG_FILENAME = '.urionlinejudge.json';

var config = void 0;

function _getConfigPath() {
  var homePath = process.env.HOME || process.env.USERPROFILE;
  return _path2.default.join(homePath, CONFIG_FILENAME);
}

function _load(reset) {
  var exists = _fs2.default.existsSync(_getConfigPath());
  var configJSON = {};

  if (exists && !reset) {
    var configPath = _getConfigPath();
    configJSON = JSON.parse(_fs2.default.readFileSync(configPath));
  }

  config = configJSON;

  return Promise.resolve();
}

function _ask(options) {
  return new Promise(function (resolve, reject) {
    (0, _read2.default)(options, function (error, answer) {
      if (error) {
        reject(error);
      } else if (_lodash2.default.isEmpty(answer)) {
        reject({ mensage: 'Can\'t use an empty string' });
      } else {
        resolve(answer);
      }
    });
  });
}

function _askForEmail() {
  return _ask({
    prompt: 'What is your email?'
  }).then(function (answer) {
    config.email = answer;
  });
}

function _askForPassword() {
  return _ask({
    prompt: 'What is your password?',
    silent: true,
    replace: '*'
  }).then(function (answer) {
    config.password = answer;
  });
}

function _askForTemplate() {
  return _ask({
    prompt: 'What is the full path for the template?'
  }).then(function (answer) {
    config.template = _path2.default.resolve(answer);
  });
}

function _save() {
  return new Promise(function (resolve) {
    var file = JSON.stringify(config, null, '  ');

    _fs2.default.writeFile(_getConfigPath(), file, function () {
      resolve(config);
    });
  });
}

var Config = function () {
  function Config() {
    _classCallCheck(this, Config);
  }

  _createClass(Config, null, [{
    key: 'load',
    value: function load(reset) {
      var save = false;

      return _load(reset).then(function () {
        if (_lodash2.default.isEmpty(config.template)) {
          save = true;
          return _askForTemplate();
        }
      }).then(function () {
        if (_lodash2.default.isEmpty(config.email)) {
          save = true;
          return _askForEmail();
        }
      }).then(function () {
        if (_lodash2.default.isEmpty(config.password)) {
          save = true;
          return _askForPassword();
        }
      }).then(function () {
        if (save) {
          return _save();
        }
      }).then(function () {
        return config;
      });
    }
  }]);

  return Config;
}();

exports.default = Config;