'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _co = require('co');

var _co2 = _interopRequireDefault(_co);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _nightmare = require('nightmare');

var _nightmare2 = _interopRequireDefault(_nightmare);

var _log = require('../utils/log');

var _log2 = _interopRequireDefault(_log);

var _progress = require('../utils/progress');

var _progress2 = _interopRequireDefault(_progress);

var _uriOnlineJudgeUrls = require('./uri-online-judge-urls.js');

var _uriOnlineJudgeUrls2 = _interopRequireDefault(_uriOnlineJudgeUrls);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var URIOnlineJudge = function () {
  function URIOnlineJudge() {
    _classCallCheck(this, URIOnlineJudge);
  }

  _createClass(URIOnlineJudge, null, [{
    key: 'submit',

    /**
     * Submit a problem to the URIOnlineJudge website.
     *
     * @param {Object} params - params object.
     * @param {string} params.email - User email.
     * @param {string} params.password - User password.
     * @param {number} params.problem - Problem number.
     * @param {string} params.file - Problem file content.
     * @returns {Promise} - Fulfill when question submited. Reject if some error occur.
     */
    value: function submit(_ref) {
      var email = _ref.email;
      var password = _ref.password;
      var problem = _ref.problem;
      var file = _ref.file;
      var language = _ref.language;

      var browser = new _nightmare2.default({ show: process.env.DEBUG });
      var progress = new _progress2.default(3);

      return _co2.default.wrap(regeneratorRuntime.mark(function submitGenerator() {
        var url, code, countTryies, answer;
        return regeneratorRuntime.wrap(function submitGenerator$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                progress.tick(0, 'log in...');

                // LOGIN
                // TODO: check if login is success
                _context.next = 3;
                return browser.goto(_uriOnlineJudgeUrls2.default.login).url();

              case 3:
                url = _context.sent;

                if (!(url === _uriOnlineJudgeUrls2.default.login)) {
                  _context.next = 7;
                  break;
                }

                _context.next = 7;
                return browser.type('input[id=email]', email).type('input[id=password]', password).click('input[type=submit]');

              case 7:

                progress.tick(1, 'submiting code...');

                code = {
                  c: 1,
                  'c++': 2,
                  java: 3,
                  python: 4,
                  python3: 5,
                  ruby: 6,
                  'c#': 7
                };

                // SUBMIT PROBLEM

                _context.next = 11;
                return browser.goto(_uriOnlineJudgeUrls2.default.problemSubmit + problem).evaluate(function (options) {
                  document.getElementById('language-id').selectedIndex = options.code;
                  editor.getSession().setValue(options.file); //eslint-disable-line
                }, { file: file, code: code[language] }).click('input[type=submit]');

              case 11:

                progress.tick(1, 'waiting for answer');

                // WAIT PROBLEM ANSWER
                countTryies = 120;
                answer = '- In queue -';
                _context.next = 16;
                return browser.goto(_uriOnlineJudgeUrls2.default.problemSubmissions);

              case 16:
                if (!(answer === '- In queue -' && countTryies-- > 0)) {
                  _context.next = 23;
                  break;
                }

                _context.next = 19;
                return browser.wait(1000).refresh().evaluate(URIOnlineJudge._getAnswer, {
                  number: problem
                });

              case 19:
                answer = _context.sent;


                progress.tick(0, answer);
                _context.next = 16;
                break;

              case 23:

                if (countTryies <= 0) {
                  answer = 'Timeout';
                }

                progress.tick();

                URIOnlineJudge.showResult({ answer: answer, problem: problem });

                // FINISH
                _context.next = 28;
                return browser.end();

              case 28:
                return _context.abrupt('return', answer);

              case 29:
              case 'end':
                return _context.stop();
            }
          }
        }, submitGenerator, this);
      }))().catch(function (error) {
        console.error(error.stack ? error.stack : error);
      });
    }

    /**
     * Print result on the command line with colors.
     *
     * @param {Object} params - params object.
     * @param {string} params.answer - Problem answer.
     * @param {number} params.problem - Problem number.
     */

  }, {
    key: 'showResult',
    value: function showResult(_ref2) {
      var answer = _ref2.answer;
      var problem = _ref2.problem;

      var color = 'white';

      var answers = [{
        answer: 'accepted',
        color: 'green'
      }, {
        answer: 'wrong',
        color: 'red'
      }, {
        answer: 'find the answer',
        color: 'red'
      }, {
        answer: 'compilation error',
        color: 'yellow'
      }, {
        answer: 'time limit exceeded',
        color: 'blue'
      }, {
        answer: 'runtime error',
        color: 'cyan'
      }, {
        answer: 'presentation error',
        color: 'gray'
      }, {
        answer: 'timeout',
        color: 'red'
      }];

      answers.forEach(function (item) {
        if (_lodash2.default.includes(answer.toLowerCase(), item.answer.toLowerCase())) {
          color = item.color;
        }
      });

      var status = _chalk2.default[color](answer + ':');

      _log2.default.status(status, problem);
    }
  }, {
    key: '_getAnswer',
    value: function _getAnswer(options) {
      console.log(options);

      var table = document.getElementById('element').children[0];
      var tbody = table.children[1];
      var answerTmp = '- In queue -';

      for (var i = 0; i < tbody.children.length; i++) {
        var tr = tbody.children[i];

        var tiny = tr.getElementsByClassName('tiny')[0].innerText;

        console.log(tiny);

        if (options.number === parseInt(tiny, 10)) {
          answerTmp = tr.getElementsByClassName('answer')[0].innerText;
          break;
        }
      }

      return answerTmp;
    }
  }]);

  return URIOnlineJudge;
}();

exports.default = URIOnlineJudge;